==> freeon-1.0.tar.bz2: freeon-1.0/MondoConfig.h <==
#define CC_VERSION_STRING "gcc (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define CFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe"
#define CONFIGURE_ARGUMENTS ""
#define CONFIG_BUILD_DATE "Tue Sep 17 10:51:00 MDT 2013"
#define CONFIG_USER "nbock@mujo"
#define F77_FUNC(name,NAME) name ## _
#define F77_FUNC_(name,NAME) name ## _
#define F77_VERSION_STRING "GNU Fortran (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define FCFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe -ffree-line-length-none"
#define FC_FUNC(name,NAME) name ## _
#define FC_FUNC_(name,NAME) name ## _
#define FC_VERSION_STRING "GNU Fortran (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define FFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe -ffixed-line-length-none"
#define GFORTRAN 1
#define HAVE_DLFCN_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIBHDF5 1
#define HAVE_LIBM 1
#define HAVE_LIBPTHREAD 1
#define HAVE_LIBZ 1
#define HAVE_MATH_H 1
#define HAVE_MAX_SCF 256
#define HAVE_MEMORY_H 1
#define HAVE_MKOSTEMP 1
#define HAVE_MKSTEMP 1
#define HAVE_MONDO_HOST "mujo"
#define HAVE_MONDO_MACH "x86_64"
#define HAVE_MONDO_PLAT "x86_64-unknown-linux-gnu"
#define HAVE_MONDO_SCRATCH "/tmp"
#define HAVE_MONDO_SYST "linux-gnu"
#define HAVE_MONDO_VRSN "3.10.7-gentoo-mujo"
#define HAVE_PTHREAD_H 1
#define HAVE_RANDOM_SEED 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRINGS_H 1
#define HAVE_STRING_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_UNISTD_H 1
#define HAVE_ZLIB_H 1
#define HDF5_VERSION 1.8.10
#define LOG_MEMORY_USAGE CALL MondoLog(DEBUG_NONE, __FILE__, "memory at "//TRIM(IntToChar(__LINE__))//": "//TRIM(IntToChar(GetMemoryUsage()))//" kiB")
#define LT_OBJDIR ".libs/"
#define PACKAGE "freeon"
#define PACKAGE_BUGREPORT "freeon-users@nongnu.org"
#define PACKAGE_NAME "freeon"
#define PACKAGE_STRING "freeon 1.0"
#define PACKAGE_TARNAME "freeon"
#define PACKAGE_URL ""
#define PACKAGE_VERSION "1.0"
#define STDC_HEADERS 1
#define VERSION "1.0"

==> freeon-1.0.1.tar.bz2: freeon-1.0.1/MondoConfig.h <==
#define CC_VERSION_STRING "gcc (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define CFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe"
#define CONFIGURE_ARGUMENTS ""
#define CONFIG_BUILD_DATE "Wed Sep 18 10:23:05 MDT 2013"
#define CONFIG_USER "nbock@mujo"
#define F77_FUNC(name,NAME) name ## _
#define F77_FUNC_(name,NAME) name ## _
#define F77_VERSION_STRING "GNU Fortran (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define FCFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe -ffree-line-length-none"
#define FC_FUNC(name,NAME) name ## _
#define FC_FUNC_(name,NAME) name ## _
#define FC_VERSION_STRING "GNU Fortran (Gentoo 4.6.3 p1.13, pie-0.5.2) 4.6.3"
#define FFLAGS_STRING "-g -O2 -march=native -msse -msse2 -mfpmath=sse -ffast-math -ftree-vectorize -pipe -ffixed-line-length-none"
#define GFORTRAN 1
#define HAVE_DLFCN_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIBHDF5 1
#define HAVE_LIBM 1
#define HAVE_LIBPTHREAD 1
#define HAVE_LIBZ 1
#define HAVE_MATH_H 1
#define HAVE_MAX_SCF 256
#define HAVE_MEMORY_H 1
#define HAVE_MKOSTEMP 1
#define HAVE_MKSTEMP 1
#define HAVE_MONDO_HOST "mujo"
#define HAVE_MONDO_MACH "x86_64"
#define HAVE_MONDO_PLAT "x86_64-unknown-linux-gnu"
#define HAVE_MONDO_SCRATCH "/tmp"
#define HAVE_MONDO_SYST "linux-gnu"
#define HAVE_MONDO_VRSN "3.10.7-gentoo-mujo"
#define HAVE_PTHREAD_H 1
#define HAVE_RANDOM_SEED 1
#define HAVE_STDINT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRINGS_H 1
#define HAVE_STRING_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_UNISTD_H 1
#define HAVE_ZLIB_H 1
#define HDF5_VERSION 1.8.10
#define LOG_MEMORY_USAGE CALL MondoLog(DEBUG_NONE, __FILE__, "memory at "//TRIM(IntToChar(__LINE__))//": "//TRIM(IntToChar(GetMemoryUsage()))//" kiB")
#define LT_OBJDIR ".libs/"
#define PACKAGE "freeon"
#define PACKAGE_BUGREPORT "freeon-users@nongnu.org"
#define PACKAGE_NAME "FreeON"
#define PACKAGE_STRING "FreeON 1.0.1"
#define PACKAGE_TARNAME "freeon"
#define PACKAGE_URL "http://www.freeon.org"
#define PACKAGE_VERSION "1.0.1"
#define STDC_HEADERS 1
#define VERSION "1.0.1"
